@@ -1,12 +1,12 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2019 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
 #   You may obtain a copy of the License at
-# 
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #   Unless required by applicable law or agreed to in writing, software
 #   distributed under the License is distributed on an "AS IS" BASIS,
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -31,12 +31,12 @@ imxMpiWrap <- function(fun) {
 ##' imxSfClient
 ##'
 ##' As of snowfall 1.84, the snowfall supervisor process
-##' stores an internal state information in a variable 
+##' stores an internal state information in a variable
 ##' named ".sfOption" that is located in the "snowfall" namespace.
 ##' The snowfall client processes store internal state
 ##' information in a variable named ".sfOption" that is located
 ##' in the global namespace.
-##' 
+##'
 ##' As long as the previous statement is true, then the current
 ##' process is a snowfall client if-and-only-if exists(".sfOption").
 imxSfClient <- function() {
@@ -48,8 +48,8 @@ omxLapply <- function(x, fun, ...) {
 	libraries <- search()
 	if ("package:snowfall" %in% libraries) {
 		return(snowfall::sfClusterApplyLB(x, fun, ...))  # nocov
-	} else if ("package:Rmpi" %in% libraries) {
-		return(Rmpi::mpi.parLapply(x, imxMpiWrap(fun), ...))  # nocov
+#	} else if ("package:Rmpi" %in% libraries) {
+#		return(Rmpi::mpi.parLapply(x, imxMpiWrap(fun), ...))  # nocov
 	} else {
 		return(lapply(x, fun, ...))
 	}
