@@ -1,18 +1,22 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2019 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
 #   You may obtain a copy of the License at
-# 
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #   Unless required by applicable law or agreed to in writing, software
 #   distributed under the License is distributed on an "AS IS" BASIS,
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
+modelIsHollowAndNotEmpty <- function(model) {
+  length(model@submodels) > 0 && modelIsHollow(model)
+}
+
 modelIsHollow <- function(model) {
 	if (!isHollow(model)) {
 		return(FALSE)
@@ -20,12 +24,12 @@ modelIsHollow <- function(model) {
 	submodels <- imxDependentModels(model)
 	if (length(submodels) == 0) return(TRUE)
 	children <- sapply(submodels, modelIsHollow)
-	return(all(children))	
+	return(all(children))
 }
 
 isHollow <- function(model) {
-	return(is.null(model@fitfunction) && 
-		length(model@matrices) == 0 && 
+	return(is.null(model@fitfunction) &&
+		length(model@matrices) == 0 &&
 		length(model@algebras) == 0)
 }
 
@@ -50,7 +54,7 @@ processHollowModel <- function(model, independents, frontendStart, indepElapsed)
 	model <- imxReplaceModels(model, independents)
 	frontendStop <- Sys.time()
 	frontendElapsed <- (frontendStop - frontendStart) - indepElapsed
-	model@output <- calculateTiming(model@output, frontendElapsed, 
+	model@output <- calculateTiming(model@output, frontendElapsed,
 		0, indepElapsed, frontendStop, independents)
 	model@output$mxVersion <- mxVersion(verbose=FALSE)
 	model@runstate$independents <- independents
@@ -58,17 +62,14 @@ processHollowModel <- function(model, independents, frontendStart, indepElapsed)
 }
 
 
-nameOptimizerOutput <- function(suppressWarnings, flatModel, matrixNames, 
-		algebraNames, parameterNames, constraintNames, computeSeq, 
+nameOptimizerOutput <- function(suppressWarnings, flatModel, matrixNames,
+		algebraNames, parameterNames, constraintNames, computeSeq,
 		output) {
 	output$mxVersion <- mxVersion(verbose=FALSE)
 	if (length(output$estimate) == length(parameterNames)) {
 		names(output$estimate) <- parameterNames
 	}
-	if (length(output$gradient) == length(parameterNames)) {
-		names(output$gradient) <- parameterNames
-	}
-	for (deriv in c("calculatedHessian", "hessian", "ihessian")) {
+	for (deriv in c("calculatedHessian")) {
 		mat <- output[[deriv]]
 		if (!is.null(mat) &&
 		    nrow(mat) == length(parameterNames) &&
@@ -83,9 +84,7 @@ nameOptimizerOutput <- function(suppressWarnings, flatModel, matrixNames,
 	if (length(output$algebras) == length(algebraNames)) {
 		names(output$algebras) <- algebraNames
 	}
-	if (length(output$standardErrors) == length(parameterNames)) {
-		rownames(output$standardErrors) <- parameterNames
-	}
+	output <- nameGenericConstraintOutput(parameterNames, constraintNames, output)
 	GDsteps <- computeSeq$steps[sapply(computeSeq$steps,function(x){is(x,"MxComputeGradientDescent")})]
 	if(length(GDsteps)){
 		lastGDstep <- GDsteps[[length(GDsteps)]] #<--If a custom compute plan has more than one GD step, use the last one
@@ -94,15 +93,16 @@ nameOptimizerOutput <- function(suppressWarnings, flatModel, matrixNames,
 	return(output)
 }
 
+
 nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep, output){
 	if(GDstep@engine=="NPSOL"){
-		
+
 		#Initialize variables:
 		cfvNames <- NULL
 		lmNames <- NULL
 		constraintRows <- NULL
 		constraintCols <- NULL
-		
+
 		#Filter extraneous elements and generate vectors of names:
 		if(length(paramNames)){lmNames <- paste(paramNames,"bound",sep=".")}
 		if(length(constraintNames) && length(GDstep@output$constraintRows) && length(GDstep@output$constraintCols)){
@@ -122,22 +122,26 @@ nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep,
 			}
 			lmNames <- c(lmNames, cfvNames)
 		}
-		
+
 		#Assign names to components, and components to 'output' list:
-		if(length(GDstep@output$constraintFunctionValues)){
-			if(length(GDstep@output$constraintFunctionValues)==length(cfvNames)){
-				names(GDstep@output$constraintFunctionValues) <- cfvNames
+		if(is.null(output$constraintFunctionValues)){
+			if(length(GDstep@output$constraintFunctionValues)){
+				if(length(GDstep@output$constraintFunctionValues)==length(cfvNames)){
+					names(GDstep@output$constraintFunctionValues) <- cfvNames
+				}
+				output$constraintFunctionValues <- GDstep@output$constraintFunctionValues
 			}
-			output$constraintFunctionValues <- GDstep@output$constraintFunctionValues
 		}
-		if(length(GDstep@output$constraintJacobian)){
-			if(ncol(GDstep@output$constraintJacobian) && ncol(GDstep@output$constraintJacobian)==length(paramNames)){
-				colnames(GDstep@output$constraintJacobian) <- paramNames
+		if(is.null(output$constraintJacobian)){
+			if(length(GDstep@output$constraintJacobian)){
+				if(ncol(GDstep@output$constraintJacobian) && ncol(GDstep@output$constraintJacobian)==length(paramNames)){
+					colnames(GDstep@output$constraintJacobian) <- paramNames
+				}
+				if(nrow(GDstep@output$constraintJacobian) && nrow(GDstep@output$constraintJacobian)==length(cfvNames)){
+					rownames(GDstep@output$constraintJacobian) <- cfvNames
+				}
+				output$constraintJacobian <- GDstep@output$constraintJacobian
 			}
-			if(nrow(GDstep@output$constraintJacobian) && nrow(GDstep@output$constraintJacobian)==length(cfvNames)){
-				rownames(GDstep@output$constraintJacobian) <- cfvNames
-			}
-			output$constraintJacobian <- GDstep@output$constraintJacobian
 		}
 		if(length(GDstep@output$LagrangeMultipliers)){
 			if(length(GDstep@output$LagrangeMultipliers)==length(lmNames)){
@@ -153,12 +157,12 @@ nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep,
 		}
 	}
 	else if(GDstep@engine=="CSOLNP" || GDstep@engine=="SLSQP"){
-		
+
 		#Initialize variables:
 		cfvNames <- NULL
 		constraintRows <- NULL
 		constraintCols <- NULL
-		
+
 		#Filter extraneous elements and generate vectors of names:
 		if(length(constraintNames) && length(GDstep@output$constraintRows) && length(GDstep@output$constraintCols)){
 			emptyConstraints <- (GDstep@output$constraintRows==0 | GDstep@output$constraintCols==0)
@@ -176,22 +180,26 @@ nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep,
 				}
 			}
 		}
-		
+
 		#Assign names to components, and components to 'output' list:
-		if(length(GDstep@output$constraintFunctionValues)){
-			if(length(GDstep@output$constraintFunctionValues)==length(cfvNames)){
-				names(GDstep@output$constraintFunctionValues) <- cfvNames
+		if(is.null(output$constraintFunctionValues)){
+			if(length(GDstep@output$constraintFunctionValues)){
+				if(length(GDstep@output$constraintFunctionValues)==length(cfvNames)){
+					names(GDstep@output$constraintFunctionValues) <- cfvNames
+				}
+				output$constraintFunctionValues <- GDstep@output$constraintFunctionValues
 			}
-			output$constraintFunctionValues <- GDstep@output$constraintFunctionValues
 		}
-		if(length(GDstep@output$constraintJacobian)){
-			if(ncol(GDstep@output$constraintJacobian) && ncol(GDstep@output$constraintJacobian)==length(paramNames)){
-				colnames(GDstep@output$constraintJacobian) <- paramNames
+		if(is.null(output$constraintJacobian)){
+			if(length(GDstep@output$constraintJacobian)){
+				if(ncol(GDstep@output$constraintJacobian) && ncol(GDstep@output$constraintJacobian)==length(paramNames)){
+					colnames(GDstep@output$constraintJacobian) <- paramNames
+				}
+				if(nrow(GDstep@output$constraintJacobian) && nrow(GDstep@output$constraintJacobian)==length(cfvNames)){
+					rownames(GDstep@output$constraintJacobian) <- cfvNames
+				}
+				output$constraintJacobian <- GDstep@output$constraintJacobian
 			}
-			if(nrow(GDstep@output$constraintJacobian) && nrow(GDstep@output$constraintJacobian)==length(cfvNames)){
-				rownames(GDstep@output$constraintJacobian) <- cfvNames
-			}
-			output$constraintJacobian <- GDstep@output$constraintJacobian
 		}
 		if(length(GDstep@output$LagrangeMultipliers)){
 			if(length(GDstep@output$LagrangeMultipliers)==length(cfvNames)){
@@ -200,7 +208,7 @@ nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep,
 			output$LagrangeMultipliers <- GDstep@output$LagrangeMultipliers
 		}
 		if(length(GDstep@output$LagrHessian)){
-			if(ncol(GDstep@output$LagrHessian) && ncol(GDstep@output$LagrHessian)==length(paramNames) && 
+			if(ncol(GDstep@output$LagrHessian) && ncol(GDstep@output$LagrHessian)==length(paramNames) &&
 				 nrow(GDstep@output$LagrHessian)==length(paramNames)){
 				dimnames(GDstep@output$LagrHessian) <- list(paramNames,paramNames)
 			}
@@ -210,6 +218,57 @@ nameGDOptimizerConstraintOutput <- function(paramNames, constraintNames, GDstep,
 	return(output)
 }
 
+
+nameGenericConstraintOutput <- function(paramNames, constraintNames, output){
+	#Name columns of vcov, if it exists:
+	if(!is.null(output$vcov)){
+		 if(ncol(output$vcov) && nrow(output$vcov) && nrow(output$vcov)==ncol(output$vcov)){
+			colnames(output$vcov) <- rownames(output$vcov)
+	}}
+
+	#Initialize variables:
+	cfvNames <- NULL
+	constraintRows <- NULL
+	constraintCols <- NULL
+
+	#Filter extraneous elements and generate vectors of names:
+	if(length(constraintNames) && length(output$constraintRows) && length(output$constraintCols)){
+		emptyConstraints <- (output$constraintRows==0 | output$constraintCols==0)
+		#Assuming that "empty" constraints have no function values...
+		constraintNames <- constraintNames[!emptyConstraints]
+		constraintRows <- output$constraintRows[!emptyConstraints]
+		constraintCols <- output$constraintCols[!emptyConstraints]
+	}
+	if(length(constraintNames) && length(constraintRows) && length(constraintCols)){
+		for(i in 1:length(constraintNames)){
+			for(co in 1:constraintCols[i]){
+				for(ro in 1:constraintRows[i]){
+					cfvNames <- c(cfvNames, paste(constraintNames[i],"[",ro,",",co,"]",sep=""))
+				}
+			}
+		}
+	}
+
+	if(length(output$constraintFunctionValues) && length(output$constraintFunctionValues)==length(cfvNames)){
+		names(output$constraintFunctionValues) <- cfvNames
+	}
+	if(length(output$constraintJacobian)){
+		if(ncol(output$constraintJacobian) && ncol(output$constraintJacobian)==length(paramNames)){
+			colnames(output$constraintJacobian) <- paramNames
+		}
+		if(nrow(output$constraintJacobian) && nrow(output$constraintJacobian)==length(cfvNames)){
+			rownames(output$constraintJacobian) <- cfvNames
+		}
+	}
+
+	#Remove clutter from output list:
+	output$constraintNames <- NULL
+	output$constraintCols <- NULL
+	output$constraintRows <- NULL
+
+	return(output)
+}
+
 processErrorConditions <- function(model, unsafe, suppressWarnings) {
 	output <- model@output
 	if (!is.null(output$status$code) && !suppressWarnings) {
@@ -270,7 +329,7 @@ optimizerMessages <- list('1' = paste('The final iterate satisfies',
 npsolWarnings <- function(prefix, status) {
 	message <- optimizerMessages[[as.character(status)]]
 	if(!is.null(message)) {
-		warning(paste(prefix, 
+		warning(paste(prefix,
 			"Optimizer returned a non-zero status code",
 			paste(status, '.', sep = ''), message), call. = FALSE)
 	}
