@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2019 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,7 +34,9 @@
 # ----------------------------------
 # Read libraries and set options.
 
-require(OpenMx)
+library(OpenMx)
+
+suppressWarnings(RNGversion("3.5"))
 
 # ----------------------------------
 # Read the data and print descriptive statistics.
@@ -64,7 +66,8 @@ biRegModelRaw <- mxModel("FIML Bivariate Regression of y on x1 and x2",
     )
 
 omxCheckError(mxRun(biRegModelRaw, suppressWarnings=TRUE),
-"The job for model 'FIML Bivariate Regression of y on x1 and x2' exited abnormally with the error message: FIML Bivariate Regression of y on x1 and x2.expectation: raw data observed but no expected means vector was provided. Add something like mxPath(from = 'one', to = manifests) to your model.")
+              paste("The job for model 'FIML Bivariate Regression of y on x1 and x2' exited abnormally with the error message:",
+                    "MxExpectationRAM: raw data observed but no expected means vector was provided. Add something like mxPath(from = 'one', to = manifests) to your model."))
 
 biRegModelRaw <- mxModel(
   biRegModelRaw,
@@ -109,7 +112,7 @@ set.seed(42)
 biRegModelRawBoot <- mxBootstrap(biRegModelRawOut, 10)
 omxCheckTrue(is.null(biRegModelRawBoot$output[["standardErrors"]]))
 bq1 <- summary(biRegModelRawBoot)[["bootstrapSE"]]
-omxCheckCloseEnough(cor(bq1, biRegModelRawOut$output$standardErrors), .89, .01)
+omxCheckCloseEnough(cor(bq1, biRegModelRawOut$output$standardErrors), 1, .16)
 
 biRegModelRawBoot <- mxBootstrap(biRegModelRawBoot)
 bq2 <- summary(biRegModelRawBoot)[["bootstrapSE"]]
