@@ -132,5 +132,8 @@ if (0) {
 run4 <- mxRun(m4)
 
 omxCheckTrue(run4$output$evaluations < run1$output$evaluations)
-#The 1 additional funeval is, of course, from the MxComputeOnce step:
-omxCheckTrue(run4$output$evaluations == run2$output$evaluations+1)
+
+# There are two additional evaluations:
+# 1 To initialize sub.fitfunction
+# 2 to evaluate sub.fitfunction
+omxCheckCloseEnough(run4$output$evaluations, run2$output$evaluations+2)
