@@ -156,6 +156,9 @@ jointWlsResults <- mxRun(jointWlsModel)
 jointDlsResults <- mxRun(jointDlsModel)
 jointUlsResults <- mxRun(jointUlsModel)
 
+expect_equal(median(log(diag(jointWlsResults$data$observedStats$acov))),
+             median(log(diag(jointDlsResults$data$observedStats$acov))), .2)
+
 ramWlsResults <- mxRun(ramWlsModel)
 
 jointResults1 <- mxRun(jointModel1, suppressWarnings = TRUE)
@@ -174,6 +177,9 @@ expect_equal(summary(jointDlsResults)$ChiDoF, 5)
 noOptResult <- mxRun(jointDlsResults, useOptimizer = FALSE)
 expect_true(is.null(summary(noOptResult)$Chi))
 
+expect_equal(length(mxGetExpected(jointWlsResults, 'standvector')),
+             summary(jointWlsResults)$observedStatistics)
+
 #------------------------------------------------------------------------------
 # Compare ML and WLS estimates
 
