@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 The OpenMx Project
+#   Copyright 2007-2018 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 
 
 library(OpenMx)
+library(testthat)
 
 # Try with 2 appearances of 'x', one starting at 1.0 and the other NA
 
@@ -56,3 +57,38 @@ m1$mat1$values[1,1] <- NA
 m1$mat2$values[1,1] <- NA
 
 omxCheckError(mxRun(m1), "Parameter 'x' has no starting value")
+
+#-----------------
+
+test_that("mismatched starting values", {
+  m2 <- mxModel(mxMatrix("Full", 2, 1, TRUE, values=c(1,2),
+                         labels="same", name="A"))
+  expect_error(mxRun(m2), "assigned multiple starting values")
+})
+
+test_that("mismatched lbound", {
+  m2 <- mxModel(mxMatrix("Full", 2, 1, TRUE, values=1,
+                         labels="same", lbound=c(.1,.2), name="A"))
+  expect_error(mxRun(m2), "assigned multiple lower bounds")
+  mxRun(omxAssignFirstParameters(m2))
+})
+
+test_that("mismatched ubound", {
+  m2 <- mxModel(mxMatrix("Full", 2, 1, TRUE, values=1,
+                         labels="same", ubound=c(.1,.2), name="A"))
+  expect_error(mxRun(m2), "assigned multiple upper bounds")
+})
+
+test_that("equal bounds", {
+  m2 <- mxModel(mxMatrix("Full", 1, 1, TRUE, values=1.5,
+                         lbound=2, ubound=1, name="A"))
+  expect_error(mxRun(m2), "greater than or equal to an upper bound")
+})
+
+test_that("mxPath bounds", {
+  lb <- seq(.75,3,length.out=10)
+  lb[6] <- NA
+  expect_error(mxPath(letters[1:5], connect = "unique.bivariate",
+                      lbound = lb, ubound = 2),
+               "2.25 is greater than or equal to upper bound")
+})
