@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2018 by the individuals mentioned in the source code history
+ *  Copyright 2007-2019 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -14,13 +14,11 @@
  *  limitations under the License.
  */
 
-#ifndef _OMXALGEBRA_H_
-#define _OMXALGEBRA_H_
+#ifndef u_OMXALGEBRA_H_
+#define u_OMXALGEBRA_H_
 
 #include "omxDefines.h"
 #include <R_ext/Rdynload.h> 
-#include <R_ext/BLAS.h>
-#include <R_ext/Lapack.h>
 
 typedef struct omxAlgebra omxAlgebra;
 
@@ -30,11 +28,14 @@ typedef struct omxAlgebra omxAlgebra;
 
 struct omxAlgebra {						// A matrix
 										//TODO: Improve encapsulation
-/* Fields unique to Algebras */
 	algebra_op_t funWrapper;					// Wrapper for the algebra function itself
 	omxMatrix** algArgs;
 	int numArgs;						// Length of args
 
+	// hack for expectations
+	omxExpectation *expectation;
+	const char *what;
+
 	omxMatrix* matrix;				// The matrix populated by this algebra
 	bool calcDimnames;
 	int verbose;
@@ -48,7 +49,6 @@ struct omxAlgebra {						// A matrix
 };
 
 /* Initialize and Destroy */
-	omxMatrix* omxInitAlgebra(omxAlgebra *oa, omxState* os);			// Constructor 
 void omxAlgebraAllocArgs(omxAlgebra *oa, int numArgs);
 void omxFillAlgebraFromTableEntry(omxAlgebra *oa, const omxAlgebraTableEntry* oate, const int realNumArgs);
 	void omxInitAlgebraWithMatrix(omxAlgebra *oa, omxMatrix* om);		// Constructor (with matrix)
@@ -73,4 +73,6 @@ void omxAlgebraPreeval(omxMatrix *mat, FitContext *fc);
 
 void omxAlgebraPrint(omxAlgebra *source, const char* d);
 
-#endif /* _OMXALGEBRA_H_ */
+void connectMatrixToExpectation(omxMatrix *result, omxExpectation *ex, const char *what);
+
+#endif /* u_OMXALGEBRA_H_ */
