@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2018 The OpenMx Project
+ *  Copyright 2007-2018 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -14,8 +14,8 @@
  *  limitations under the License.
  */
 
-#ifndef _OMX_NPSOL_SPECIFIC_H
-#define _OMX_NPSOL_SPECIFIC_H
+#ifndef u_OMX_NPSOL_SPECIFIC_H
+#define u_OMX_NPSOL_SPECIFIC_H
 
 /* NPSOL-specific globals */
 extern const double NPSOL_BIGBND;
@@ -30,4 +30,4 @@ void omxNPSOLConfidenceIntervals(omxMatrix *fitMatrix, FitContext *fc, double to
  
 void omxSetNPSOLOpts(SEXP options);
 
-#endif // #define _OMX_NPSOL_SPECIFIC_H
+#endif // #define u_OMX_NPSOL_SPECIFIC_H
