@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2018 The OpenMx Project
+ *  Copyright 2007-2018 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -14,8 +14,8 @@
  *  limitations under the License.
  */
 
-#ifndef _OMX_R_FITFUNCTION_
-#define _OMX_R_FITFUNCTION_
+#ifndef u_OMX_R_FITFUNCTION_
+#define u_OMX_R_FITFUNCTION_
 
 struct omxRFitFunction : omxFitFunction {
 
@@ -30,4 +30,4 @@ struct omxRFitFunction : omxFitFunction {
 
 void omxInitRFitFunction(omxFitFunction* oo);
 
-#endif /* _OMX_R_FITFUNCTION_ */
+#endif /* u_OMX_R_FITFUNCTION_ */
