@@ -93,6 +93,7 @@ class omxFreeVar {
 struct FreeVarGroup {
 	std::vector<int> id;              // see omxGlobal::deduplicateVarGroups
 	std::vector< omxFreeVar* > vars;
+  std::map< const char *, int, cstrCmp > byName;
 
 	// see cacheDependencies
 	std::vector<bool> dependencies;
@@ -102,6 +103,7 @@ struct FreeVarGroup {
 	int lookupVar(int matrix, int row, int col);
 	int lookupVar(omxMatrix *matrix, int row, int col);
 	//int lookupVar(int id);
+	void reIndex();
 	void cacheDependencies(omxState *os);
 	void markDirty(omxState *os);
 	void log(omxState *os);
@@ -139,9 +141,10 @@ class omxConstraint {
   std::vector<bool> seenActive;
   Eigen::ArrayXXd initialJac;
   bool strict;
+  int verbose;
 
 	//Constraints created by backend for CIs use this, the base-class constructor:
-  omxConstraint(const char *name) : name(name), linear(0) {};
+  omxConstraint(const char *name) : name(name), linear(0), verbose(0) {};
 	virtual ~omxConstraint() {};
   virtual void getDim(int *rowsOut, int *colsOut) const = 0;
 	virtual void refreshAndGrab(FitContext *fc, double *out) = 0;
@@ -159,7 +162,6 @@ class UserConstraint : public omxConstraint {
 	omxMatrix *pad;
 	omxMatrix *jacobian;
 	std::vector<int> jacMap;
-  int verbose;
 	void refresh(FitContext *fc);
 	UserConstraint(const char *name) : super(name) {};
 
@@ -262,6 +264,7 @@ class omxGlobal {
 	double llScale;
 	int debugProtectStack;
 	bool rowLikelihoodsWarning;
+	bool RAMmultilevelWarning;
 	double feasibilityTolerance;
 	double optimalityTolerance;
 	int majorIterations;
