@@ -15,6 +15,7 @@
 
 
 library(OpenMx)
+library(MASS)
 library(testthat)
 context("AlgebraCompute")
 
@@ -58,6 +59,7 @@ model <- mxModel(model, mxAlgebra(A * (B + A), name = 'parens'))
 model <- mxModel(model, mxAlgebraFromString("A * (B + A)", name = 'parens2'))
 model <- mxModel(model, mxAlgebra(A, name = 'test0'))
 model <- mxModel(model, mxAlgebra(solve(A), name = 'test1'))
+model <- mxModel(model, mxAlgebra(mpinv(C), name = 'test1a'))
 model <- mxModel(model, mxAlgebra(t(A), name = 'test2'))
 model <- mxModel(model, mxAlgebra(A ^ B, name = 'test3'))
 model <- mxModel(model, mxAlgebra(t(A) ^ B, name = 'test3a'))
@@ -321,6 +323,7 @@ omxCheckCloseEnough(modelOut[['test0']]$result, A$values, 0.001)
 omxCheckCloseEnough(modelOut[['parens']]$result, A$values * (B$values + A$values), 0.001)
 omxCheckCloseEnough(modelOut[['parens2']]$result, A$values * (B$values + A$values), 0.001)
 omxCheckCloseEnough(modelOut[['test1']]$result, solve(A$values), 0.001)
+omxCheckCloseEnough(modelOut[['test1a']]$result, mpinv(C$values), 0.001)
 omxCheckCloseEnough(modelOut[['test2']]$result, t(A$values), 0.001)
 omxCheckCloseEnough(modelOut[['test3']]$result, A$values ^ B$values, 0.001)
 omxCheckCloseEnough(modelOut[['test3a']]$result, t(A$values) ^ B$values, 0.001)
